#!/usr/bin/python

import numpy as np
from matplotlib.pylab import *

# Setup figure and subplots
f0 = figure(num = 0, figsize = (12, 8))#, dpi = 300)
ax01 = subplot2grid((2, 2), (0, 0))
ax02 = subplot2grid((2, 2), (0, 1))
ax03 = subplot2grid((2, 2), (1, 0), colspan=2, rowspan=1)

# Panel 1: Function
ax01.set_title('1D Profile')
ax02.set_title('Vector')
ax01.grid("on")

xmin = -1.0
xmax = 1.0
x  = arange(xmin, xmax, 0.01)
a0 = 1
f0 = 1
phase = pi/2
yp1 = a0*np.cos(2*np.pi*f0*x - phase)

fig = figure(0)   
ax01.set_xlim([-1,1])
ax01.set_ylim([-3,3])
p011, = ax01.plot(x,yp1,'b-', label="yp1")
p011.set_data(x,yp1)

# Panel 2: Vector
soa = np.array( [ [f0,0,a0*cos(phase),a0*sin(phase)] ]) 
X,Y,U,V = zip(*soa)
ax02.quiver(X,Y,U,V,angles='xy',scale_units='xy',scale=1, pivot='middle')
ax02.grid("on")
ax02.set_xlim([-0.5,5.5])
ax02.set_ylim([-3,3])


# Sliders
ax03.set_frame_on(False)
ax03.xaxis.set_visible(False)
ax03.yaxis.set_visible(False)

axcolor = 'lightgoldenrodyellow'
axfreq = plt.axes([0.2, 0.2, 0.65, 0.03], axisbg=axcolor)
axamp  = plt.axes([0.2, 0.25, 0.65, 0.03], axisbg=axcolor)
axphase  = plt.axes([0.2, 0.3, 0.65, 0.03], axisbg=axcolor)

sfreq = Slider(axfreq, 'Freq', 0.1, 5.0, valinit=f0)
samp = Slider(axamp, 'Amp', 0.1, 5.0, valinit=a0)
sphase = Slider(axphase, 'Phase', -180,180, valinit=180*phase/pi)

def update(val):
    a0 = samp.val
    f0 = sfreq.val
    phase = pi*sphase.val/180
    p011.set_ydata(a0*np.cos(2*np.pi*f0*x - phase))
    ax02.cla()
    ax02.grid("on")
    ax02.set_xlim([-0.5,5.5])
    ax02.set_ylim([-3,3])
    ax02.set_title('Vector')
    soa = np.array( [ [f0,0,a0*cos(phase),a0*sin(phase)] ]) 
    X,Y,U,V = zip(*soa)
    ax02.quiver(X,Y,U,V,angles='xy',scale_units='xy',scale=1, pivot='middle')
    fig.canvas.draw_idle()
sfreq.on_changed(update)
samp.on_changed(update)
sphase.on_changed(update)

show()
