#!/usr/bin/python

import numpy as np
from matplotlib.pylab import *

# Setup figure and subplots
f0 = figure(num = 0, figsize = (12, 8))#, dpi = 300)
ax01 = subplot2grid((2, 2), (0, 0))
ax02 = subplot2grid((2, 2), (0, 1))
ax03 = subplot2grid((2, 2), (1, 0), colspan=2, rowspan=1)

# Panel 1: Function
ax01.set_title('1D Profiles')
ax02.set_title('Vectors')
ax01.grid("on")

xmin = 0.0
xmax = 2.0
x  = np.arange(xmin, xmax, 0.01)

#a0 = 1
#f0 = 1
#phase = pi/2
#yp1 = a0*np.cos(2*np.pi*f0*x - phase)

amp1 = 4/(np.pi*1)
phase1 = 0
s1 = amp1*np.sin(1*np.pi*x + phase1)

amp3 = 4/(np.pi*3)
phase3 = 0
s3 = amp3*np.sin(3*np.pi*x + phase3)

amp5 = 4/(np.pi*5)
phase5 = 0
s5 = amp5*np.sin(5*np.pi*x + phase5)

sum = s1 + s3 + s5

#plt.grid("on")
#profile1, = plt.plot(x,s1, lw=1, color='red')
#profile3, = plt.plot(x,s3, lw=1, color='green')
#profile5, = plt.plot(x,s5, lw=1, color='blue')
#profileSum, = plt.plot(x,sum, lw=3, color='black')
#plt.axis([0, 2, -2,2])

fig = figure(0)   
#ax01.set_xlim([-1,1])
ax01.set_ylim([-2,2])
#ax01.set_xlim([-1,1])
#ax01.set_ylim([-3,3])
p011, = ax01.plot(x,s1,'b-', label="s1", color='blue')
p011.set_data(x,s1)
p011, = ax01.plot(x,s3,'b-', label="s3", color='green')
p011.set_data(x,s3)
p011, = ax01.plot(x,s5,'b-', label="s5", color='red')
p011.set_data(x,s5)
p011, = ax01.plot(x,sum,'b-', label="sum", lw=3, color='black')
p011.set_data(x,sum)

# Panel 2: Vector
soa = np.array( [ [1,0,amp1*cos(phase1),amp1*sin(phase1),1], 
                  [3,0,amp3*cos(phase3),amp3*sin(phase3),2], 
                  [5,0,amp5*cos(phase5),amp5*sin(phase5),3] ]) 
#soa = np.array( [ [f0,0,a0*cos(phase),a0*sin(phase)] ]) 
X,Y,U,V,C = zip(*soa)
ax02.quiver(X,Y,U,V,C,angles='xy',scale_units='xy',scale=1, pivot='middle')
ax02.grid("on")
ax02.set_xlim([-0.5,5.5])
ax02.set_ylim([-3,3])


# Sliders
ax03.set_frame_on(False)
ax03.xaxis.set_visible(False)
ax03.yaxis.set_visible(False)

axcolor = 'lightgoldenrodyellow'
axamp1  = plt.axes([0.25, 0.30, 0.65, 0.03], axisbg=axcolor)
axphase1 = plt.axes([0.25, 0.25, 0.65, 0.03], axisbg=axcolor)
axamp3  = plt.axes([0.25, 0.20, 0.65, 0.03], axisbg=axcolor)
axphase3 = plt.axes([0.25, 0.15, 0.65, 0.03], axisbg=axcolor)
axamp5  = plt.axes([0.25, 0.10, 0.65, 0.03], axisbg=axcolor)
axphase5 = plt.axes([0.25, 0.05, 0.65, 0.03], axisbg=axcolor)

samp1 = Slider(axamp1, 'Amp', 0.0, 2.0, valinit=amp1)
sphase1 = Slider(axphase1, 'Phase', -180,180, valinit=180*phase1/pi)
samp3 = Slider(axamp3, 'Amp', 0.0, 2.0, valinit=amp3)
sphase3 = Slider(axphase3, 'Phase', -180,180, valinit=180*phase3/pi)
samp5 = Slider(axamp5, 'Amp', 0.0, 2.0, valinit=amp5)
sphase5 = Slider(axphase5, 'Phase', -180,180, valinit=180*phase5/pi)

def update(val):
    amp1 = samp1.val
    phase1 = np.pi*sphase1.val/180
    amp3 = samp3.val
    phase3 = np.pi*sphase3.val/180
    amp5 = samp5.val
    phase5 = np.pi*sphase5.val/180
    s1 = amp1*np.sin(1*np.pi*x + phase1)
    s3 = amp3*np.sin(3*np.pi*x + phase3)
    s5 = amp5*np.sin(5*np.pi*x + phase5)
    sum = s1 + s3 + s5
    #a0 = samp.val
    #f0 = sfreq.val
    #phase = pi*sphase.val/180
    #p011.set_ydata(a0*np.cos(2*np.pi*f0*x - phase))
    ax01.cla()
    ax01.grid("on")
    ax01.set_ylim([-2,2])
    ax01.set_title('1D Profiles')
    p011, = ax01.plot(x,s1,'b-', label="s1", color='blue')
    p011.set_data(x,s1)
    p011, = ax01.plot(x,s3,'b-', label="s3", color='green')
    p011.set_data(x,s3)
    p011, = ax01.plot(x,s5,'b-', label="s5", color='red')
    p011.set_data(x,s5)
    p011, = ax01.plot(x,sum,'b-', label="sum", lw=3, color='black')
    p011.set_data(x,sum)
    ax02.cla()
    ax02.grid("on")
    ax02.set_xlim([-0.5,5.5])
    ax02.set_ylim([-3,3])
    ax02.set_title('Vectors')
    soa = np.array( [ [1,0,amp1*cos(phase1),amp1*sin(phase1),1], 
                    [3,0,amp3*cos(phase3),amp3*sin(phase3),2], 
                    [5,0,amp5*cos(phase5),amp5*sin(phase5),3] ]) 
#    soa = np.array( [ [f0,0,a0*cos(phase),a0*sin(phase)] ]) 
    X,Y,U,V,C = zip(*soa)
    ax02.quiver(X,Y,U,V,C,angles='xy',scale_units='xy',scale=1, pivot='middle')
    fig.canvas.draw_idle()
samp1.on_changed(update)
sphase1.on_changed(update)
samp3.on_changed(update)
sphase3.on_changed(update)
samp5.on_changed(update)
sphase5.on_changed(update)
#sfreq.on_changed(update)
#samp.on_changed(update)
#sphase.on_changed(update)

show()
