#!/usr/bin/python

import numpy as np
import matplotlib.pyplot as plt
from matplotlib.widgets import Slider, Button

# Adapted from http://matplotlib.org/users/screenshots.html

fig, ax = plt.subplots()
plt.subplots_adjust(bottom=0.40)
x = np.arange(0.0, 2.0, 0.01)

amp1 = -1/(np.pi*1)
phase1 = 0
s1 = amp1*np.sin(1*np.pi*x + phase1)

amp2 = -1/(np.pi*2)
phase2 = 0
s2 = amp2*np.sin(2*np.pi*x + phase2)

amp3 = -1/(np.pi*3)
phase3 = 0
s3 = amp3*np.sin(3*np.pi*x + phase3)

sum = s1 + s2 + s3

plt.grid("on")
profile1, = plt.plot(x,s1, lw=1, color='red')
profile2, = plt.plot(x,s2, lw=1, color='green')
profile3, = plt.plot(x,s3, lw=1, color='blue')
profileSum, = plt.plot(x,sum, lw=3, color='black')
plt.axis([0, 2, -0.5, 0.5])

axcolor = 'lightgoldenrodyellow'
axamp1  = plt.axes([0.25, 0.30, 0.65, 0.03], axisbg=axcolor)
axphase1 = plt.axes([0.25, 0.25, 0.65, 0.03], axisbg=axcolor)
axamp2  = plt.axes([0.25, 0.20, 0.65, 0.03], axisbg=axcolor)
axphase2 = plt.axes([0.25, 0.15, 0.65, 0.03], axisbg=axcolor)
axamp3  = plt.axes([0.25, 0.10, 0.65, 0.03], axisbg=axcolor)
axphase3 = plt.axes([0.25, 0.05, 0.65, 0.03], axisbg=axcolor)

samp1 = Slider(axamp1, 'Amp1', -1.0, 1.0, valinit=amp1)
sphase1 = Slider(axphase1, 'Phase1', -180,180, valinit=180*phase1/np.pi)
samp2 = Slider(axamp2, 'Amp2', -1.0, 1.0, valinit=amp2)
sphase2 = Slider(axphase2, 'Phase2', -180,180, valinit=180*phase2/np.pi)
samp3 = Slider(axamp3, 'Amp3', -1.0, 1.0, valinit=amp3)
sphase3 = Slider(axphase3, 'Phase3', -180,180, valinit=180*phase3/np.pi)

def update(val):
    amp1 = samp1.val
    phase1 = np.pi*sphase1.val/180
    amp2 = samp2.val
    phase2 = np.pi*sphase2.val/180
    amp3 = samp3.val
    phase3 = np.pi*sphase3.val/180
    s1 = amp1*np.sin(1*np.pi*x + phase1)
    s2 = amp2*np.sin(2*np.pi*x + phase2)
    s3 = amp3*np.sin(3*np.pi*x + phase3)
    sum = s1 + s2 + s3
    profile1.set_ydata(s1)
    profile2.set_ydata(s2)
    profile3.set_ydata(s3)
    profileSum.set_ydata(sum)
    fig.canvas.draw_idle()
sphase1.on_changed(update)
samp1.on_changed(update)
sphase2.on_changed(update)
samp2.on_changed(update)
sphase3.on_changed(update)
samp3.on_changed(update)

plt.show()
