#!/usr/bin/python

import numpy as np
from matplotlib.pylab import *

# Setup figure and subplots
f0 = figure(num = 0, figsize = (12, 8))#, dpi = 300)
ax01 = subplot2grid((2, 2), (0, 0))
ax02 = subplot2grid((2, 2), (0, 1))
ax03 = subplot2grid((2, 2), (1, 0), colspan=2, rowspan=1)

# Panel 1: Function
ax01.set_title('1D Profile')
ax01.grid("on")

xmin = -5.0
xmax = 5.0
N = 256
x = arange(xmin,xmax,10./(2*N))
a0 = 0.5
sigma = 1
yp1 = a0*np.exp(-x**2/sigma)
fft_y = abs(fft(yp1))
fft_y= fftshift(fft_y)

fig = figure(0)   
#ax01.set_xlim([-1,1])
ax01.set_ylim([0,1])
p011, = ax01.plot(x,yp1,'b-', label="yp1")
p011.set_data(x,yp1)

# Panel 2: FT
ax02.set_title('Fourier transform')
p012, = ax02.plot(abs(fft_y),'.-b')
ax02.grid("on")
ax02.set_xlim([N-16,N+16])
ax02.set_ylim([0,abs(fft_y).max()*2.5])
#ax02.set_ylim([-3,3])
#ax02.xaxis.set_visible(False)

# Sliders
ax03.set_frame_on(False)
ax03.xaxis.set_visible(False)
ax03.yaxis.set_visible(False)

axcolor = 'lightgoldenrodyellow'
axamp  = plt.axes([0.2, 0.30, 0.65, 0.03], axisbg=axcolor)
axsigma  = plt.axes([0.2, 0.25, 0.65, 0.03], axisbg=axcolor)

samp = Slider(axamp, 'Amp', 0.1, 2.0, valinit=a0)
ssigma = Slider(axsigma, 'Sigma', 0.01,10.0, valinit=sigma)

def update(val):
    a0 = samp.val
    sigma = ssigma.val
    yp1 = a0*np.exp(-x**2/sigma)
    fft_y = abs(fft(yp1))
    fft_y= fftshift(fft_y)
    
    p011.set_ydata(yp1)
    p012.set_ydata(fft_y)
    #ax02.cla()
    #ax02.grid("on")
    #ax02.set_xlim([-0.5,5.5])
    #ax02.set_ylim([-3,3])
    #ax02.set_title('Vector')
    #soa = np.array( [ [f0,0,a0*cos(sigma),a0*sin(sigma)] ]) 
    #X,Y,U,V = zip(*soa)
    #ax02.quiver(X,Y,U,V,angles='xy',scale_units='xy',scale=1, pivot='middle')
    fig.canvas.draw_idle()
samp.on_changed(update)
ssigma.on_changed(update)

show()
